package com.bonus.material.repair.service;

import java.util.List;
import com.bonus.material.repair.domain.RepairApplyDetails;

/**
 * 维修详细Service接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface IRepairApplyDetailsService {
    /**
     * 查询维修详细
     * 
     * @param id 维修详细主键
     * @return 维修详细
     */
    public RepairApplyDetails selectRepairApplyDetailsById(Long id);

    /**
     * 查询维修详细列表
     * 
     * @param repairApplyDetails 维修详细
     * @return 维修详细集合
     */
    public List<RepairApplyDetails> selectRepairApplyDetailsList(RepairApplyDetails repairApplyDetails);

    /**
     * 新增维修详细
     * 
     * @param repairApplyDetails 维修详细
     * @return 结果
     */
    public int insertRepairApplyDetails(RepairApplyDetails repairApplyDetails);

    /**
     * 修改维修详细
     * 
     * @param repairApplyDetails 维修详细
     * @return 结果
     */
    public int updateRepairApplyDetails(RepairApplyDetails repairApplyDetails);

    /**
     * 批量删除维修详细
     * 
     * @param ids 需要删除的维修详细主键集合
     * @return 结果
     */
    public int deleteRepairApplyDetailsByIds(Long[] ids);

    /**
     * 删除维修详细信息
     * 
     * @param id 维修详细主键
     * @return 结果
     */
    public int deleteRepairApplyDetailsById(Long id);
}
