package com.bonus.material.repair.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.repair.domain.RepairApplyDetails;
import com.bonus.material.repair.service.IRepairApplyDetailsService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 维修详细Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "维修详细接口")
@RestController
@RequestMapping("/repair_apply_details")
public class RepairApplyDetailsController extends BaseController {
    @Autowired
    private IRepairApplyDetailsService repairApplyDetailsService;

    /**
     * 查询维修详细列表
     */
    @ApiOperation(value = "查询维修详细列表")
    @RequiresPermissions("repair:details:list")
    @GetMapping("/list")
    public TableDataInfo list(RepairApplyDetails repairApplyDetails) {
        startPage();
        List<RepairApplyDetails> list = repairApplyDetailsService.selectRepairApplyDetailsList(repairApplyDetails);
        return getDataTable(list);
    }

    /**
     * 导出维修详细列表
     */
    @ApiOperation(value = "导出维修详细列表")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:details:export")
    @SysLog(title = "维修详细", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出维修详细")
    @PostMapping("/export")
    public void export(HttpServletResponse response, RepairApplyDetails repairApplyDetails) {
        List<RepairApplyDetails> list = repairApplyDetailsService.selectRepairApplyDetailsList(repairApplyDetails);
        ExcelUtil<RepairApplyDetails> util = new ExcelUtil<RepairApplyDetails>(RepairApplyDetails.class);
        util.exportExcel(response, list, "维修详细数据");
    }

    /**
     * 获取维修详细详细信息
     */
    @ApiOperation(value = "获取维修详细详细信息")
    @RequiresPermissions("repair:details:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(repairApplyDetailsService.selectRepairApplyDetailsById(id));
    }

    /**
     * 新增维修详细
     */
    @ApiOperation(value = "新增维修详细")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:details:add")
    @SysLog(title = "维修详细", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增维修详细")
    @PostMapping
    public AjaxResult add(@RequestBody RepairApplyDetails repairApplyDetails) {
        try {
            return toAjax(repairApplyDetailsService.insertRepairApplyDetails(repairApplyDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改维修详细
     */
    @ApiOperation(value = "修改维修详细")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:details:edit")
    @SysLog(title = "维修详细", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改维修详细")
    @PutMapping
    public AjaxResult edit(@RequestBody RepairApplyDetails repairApplyDetails) {
        try {
            return toAjax(repairApplyDetailsService.updateRepairApplyDetails(repairApplyDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除维修详细
     */
    @ApiOperation(value = "删除维修详细")
    @PreventRepeatSubmit
    @RequiresPermissions("repair:details:remove")
    @SysLog(title = "维修详细", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除维修详细")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(repairApplyDetailsService.deleteRepairApplyDetailsByIds(ids));
    }
}
